<!doctype html>
<html lang="{{ config('app.locale') }}" itemscope itemtype="http://schema.org/WebPage">

<head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title> {{ $general->siteName(__($pageTitle)) }}</title>
    <meta name="csrf-token" content="{{ csrf_token() }}">

    @include('partials.seo')

    <link href="https://fonts.gstatic.com" rel="preconnect">
    <link href="https://fonts.googleapis.com/css2?family=Montserrat:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap" rel="stylesheet">
    <link href="{{ asset($activeTemplateTrue . 'css/fontawesome-all.min.css') }}" rel="stylesheet">
    <link href="{{ asset('assets/global/css/bootstrap.min.css') }}" rel="stylesheet">
    <link href="{{ asset('assets/global/css/all.min.css') }}" rel="stylesheet">
    <link href="{{ asset($activeTemplateTrue . 'css/swiper.min.css') }}" rel="stylesheet">
    <link href="{{ asset('assets/global/css/line-awesome.min.css') }}" rel="stylesheet" />
    <link href="{{ asset($activeTemplateTrue . 'css/animate.css') }}" rel="stylesheet">
    <link href="{{ asset($activeTemplateTrue . 'css/style.css') }}" rel="stylesheet">
    <link href="{{ asset($activeTemplateTrue . 'css/bootstrap-fileinput.css') }}" rel="stylesheet">
    <link href="{{ asset($activeTemplateTrue . 'css/custom.css') }}" rel="stylesheet">

    @stack('style-lib')
    @stack('style')

    <link href="{{ asset($activeTemplateTrue . 'css/color.php') }}?color={{ $general->base_color }}&secondColor={{ $general->secondary_color }}" rel="stylesheet">
</head>

<body @stack('context')>

    @php
        $categories = App\Models\Category::where('status', 1)
            ->with([
                'subcategories' => function ($subcategory) {
                    $subcategory->where('status', 1);
                },
            ])
            ->get(['name', 'id']);
    @endphp
    @include($activeTemplate . 'partials.preloader')
    @include($activeTemplate . 'partials.master_header')
    <a class="scrollToTop" href="#"><i class="las la-angle-double-up"></i></a>

    @include($activeTemplate . 'partials.breadcrumb')
    @yield('content')

    @include($activeTemplate . 'partials.footer')
    <div class="modal fade" id="notifyModal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="staticBackdropLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Confirmation Alert!')</h5>
                    <button class="btn-close btn-close-white" data-bs-dismiss="modal" type="button" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                </div>
            </div>
        </div>
    </div>

    <!-- jQuery first, then Popper.js, then Bootstrap JS -->
    <script src="{{ asset('assets/global/js/jquery-3.6.0.min.js') }}"></script>
    <script src="{{ asset('assets/global/js/bootstrap.bundle.min.js') }}"></script>
    <script src="{{ asset('assets/global/js/global.js') }}"></script>
    <script src="{{ asset($activeTemplateTrue . 'js/swiper.min.js') }}"></script>
    <script src="{{ asset($activeTemplateTrue . 'js/jquery.syotimer.js') }}"></script>
    <script src="{{ asset($activeTemplateTrue . 'js/syotimer.lang.js') }}"></script>
    <script src="{{ asset($activeTemplateTrue . 'js/wow.min.js') }}"></script>
    <script src="{{ asset($activeTemplateTrue . 'js/main.js') }}"></script>
    <script src="{{ asset('assets/global/js/pusher.min.js') }}"></script>


    @stack('script-lib')

    @include('partials.notify')

    @include('partials.plugins')

    @stack('script')


    <script>
        (function($) {
            "use strict";

            $('.showFilterBtn').on('click', function() {
                $('.responsive-filter-card').slideToggle();
            });

            Array.from(document.querySelectorAll('table')).forEach(table => {
                let heading = table.querySelectorAll('thead tr th');
                Array.from(table.querySelectorAll('tbody tr')).forEach((row) => {
                    Array.from(row.querySelectorAll('td')).forEach((column, i) => {
                        (column.colSpan == 100) || column.setAttribute('data-label', heading[i].innerText)
                    });
                });
            });

            $('.subscribe-form').on('submit', function(e) {
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    }
                });
                e.preventDefault();
                var email = $('input[name=email]').val();
                $.post('{{ route('subscribe') }}', {
                    email: email
                }, function(response) {
                    if (response.errors) {
                        for (var i = 0; i < response.errors.length; i++) {
                            iziToast.error({
                                message: response.errors[i],
                                position: "topRight"
                            });
                        }
                    } else {
                        iziToast.success({
                            message: response.success,
                            position: "topRight"
                        });
                    }
                });
            });


            let userId = "{{ auth()->id() }}";

            Pusher.logToConsole = true;
            var pusher = new Pusher("{{ @$general->pusher_config->app_key }}", {
                cluster: "{{ @$general->pusher_config->cluster }}",
            });

            const pusherConnection = (eventName, callback) => {
                pusher.connection.bind('connected', () => {
                    const SOCKET_ID = pusher.connection.socket_id;
                    const CHANNEL_NAME = `private-${eventName}`;
                    const BASE_URL = "{{ route('home') }}";
                    const url = `${BASE_URL}/pusher/auth/${SOCKET_ID}/${CHANNEL_NAME}`
                    pusher.config.authEndpoint = url;
                    let channel = pusher.subscribe(CHANNEL_NAME);
                    channel.bind('pusher:subscription_succeeded', function() {
                        channel.bind(eventName, function(data) {
                            callback(data)
                        })
                    });
                });
            };

            pusherConnection("send-notification", joinRequestModal);


            let modal = $("#notifyModal");

            function joinRequestModal(data) {
                if (userId == data.hostId) {
                    modal.find('.modal-body').html(data.html);
                    modal.modal('show')
                }
            }

            pusherConnection("accept-join-request", acceptJoinRequest);

            function acceptJoinRequest(data) {
                if (userId == data.userId) {
                    window.location.href = data.redirectUrl;
                }
                if (userId == data.hostId) {
                    $('#chatJoinBodyScroll').append(data.html);
                }
            }


            pusherConnection("reject-join-request", rejectJoinRequest);

            function rejectJoinRequest(data) {
                if (userId == data.userId) {
                    let rejectMessage = `<div class="text-center">
                                        <i class="las la-4x la-times-circle"></i>
                                        <h5>@lang('Your join request has been rejected by the host')</h5>
                                    </div>`
                    $('.join-pending').html(rejectMessage);
                    setTimeout(() => {
                        window.location.href = data.redirectUrl;
                    }, 3000);
                }
            }


            pusherConnection("conversation-message", conversationMessage);

            function conversationMessage(data) {
                let members = data.membersId;
                if (members.includes(Number(userId))) {
                    $('#chatBodyScroll').append(data.html);
                    scrollHeight();
                }
            }

            pusherConnection("cancel-party", cancelParty);

            function cancelParty(data) {
                let cancelMemberId = data.allMemberId;
                if (cancelMemberId.includes(Number(userId))) {
                    window.location.href = data.redirectUrl;
                }
            }

            pusherConnection("reload-party", reloadParty);

            function reloadParty(data) {
                let cancelMemberId = data.allMemberId;
                if (cancelMemberId.includes(Number(userId))) {
                    window.location.reload();
                }
            }

            $('#partyJoinForm').submit(function(e) {
                e.preventDefault();
                let submitBtn = $(this).find('button');
                submitBtn.prop('disabled', true);
                $('.join-form-area').addClass('d-none');
                $('.join-pending').removeClass('d-none');

                const partyCode = $('[name=party_code]').val();
                if (!partyCode) {
                    notify('error', 'Party code is required');
                    return;
                }

                $.ajax({
                    type: "POST",
                    url: "{{ route('user.watch.party.join.request') }}",
                    data: {
                        _token: "{{ csrf_token() }}",
                        party_code: partyCode
                    },
                    success: function(response) {
                        if (response.error) {
                            $('.join-pending').addClass('d-none');
                            $('.join-form-area').removeClass('d-none');
                            submitBtn.prop('disabled', false);
                            notify('error', response.error);
                            return;
                        }

                        if (response.redirect_url) {
                            window.location.href = response.redirect_url;
                        }

                    }
                });
            });

            $(document).on('click', '.joinRejectBtn', function(e) {
                let rejectBtn = $(this);
                let acceptBtn = $('.joinAcceptBtn');
                rejectBtn.prop('disabled', true);
                acceptBtn.prop('disabled', true);
                $.ajax({
                    type: "POST",
                    url: `{{ route('user.watch.party.request.reject') }}/${$(this).data('memberid')}`,
                    data: {
                        _token: "{{ csrf_token() }}",
                    },
                    success: function(response) {
                        if (response.error) {
                            rejectBtn.prop('disabled', true);
                            acceptBtn.prop('disabled', true);
                            notify('error', response.error);
                            return;
                        }
                        notify('success', response.success);
                        modal.modal('hide');
                    }
                });
            });

            $(document).on('click', '.joinAcceptBtn', function(e) {
                let rejectBtn = $(this);
                let acceptBtn = $('.joinRejectBtn');
                rejectBtn.prop('disabled', true);
                acceptBtn.prop('disabled', true);
                $.ajax({
                    type: "POST",
                    url: `{{ route('user.watch.party.request.accept') }}/${$(this).data('memberid')}`,
                    data: {
                        _token: "{{ csrf_token() }}",
                    },
                    success: function(response) {
                        if (response.error) {
                            rejectBtn.prop('disabled', true);
                            acceptBtn.prop('disabled', true);
                            notify('error', response.error);
                            return;
                        }
                        notify('success', response.success);
                        modal.modal('hide');
                    }
                });
            });

            $("#messageForm").on('submit', function(e) {
                e.preventDefault();

                let data = {
                    _token: "{{ csrf_token() }}",
                    message: $('[name=message]').val(),
                    party_id: "{{ @$partyRoom->id }}"
                }

                $.ajax({
                    url: "{{ route('user.watch.party.send.message') }}",
                    method: "POST",
                    data: data,
                    success: function(response) {
                        if (response.error) {
                            notify('error', response.error);
                        } else {
                            $('#messageForm')[0].reset();
                            scrollHeight();
                        }
                    }
                });
            });

            function scrollHeight() {
                if ($('#chatBodyScroll').length) {
                    $('#chatBodyScroll').animate({
                        scrollTop: $('#chatBodyScroll')[0].scrollHeight
                    });
                }
            }
            scrollHeight();

        })(jQuery);
    </script>
</body>

</html>
